pub enum InputMessageContent {
InputTextMessageContent(InputTextMessageContent),
InputLocationMessageContent(InputLocationMessageContent),
InputVenueMessageContent(InputVenueMessageContent),
InputContactMessageContent(InputContactMessageContent),
}Expand description
This object represents the content of a message to be sent as a result of an inline query. Telegram clients currently support the following 4 types:
Variants
InputTextMessageContent(InputTextMessageContent)
Represents the content of a text message to be sent as the result of an inline query.
InputLocationMessageContent(InputLocationMessageContent)
Represents the content of a location message to be sent as the result of an inline query.
InputVenueMessageContent(InputVenueMessageContent)
Represents the content of a venue message to be sent as the result of an inline query.
InputContactMessageContent(InputContactMessageContent)
Represents the content of a contact message to be sent as the result of an inline query.