Struct telegram_bot_ars::types::requests::AnswerCallbackQuery
source · pub struct AnswerCallbackQuery<'t> { /* private fields */ }Expand description
Use this method to send answers to callback queries sent from inline keyboards. The answer will be displayed to the user as a notification at the top of the chat screen or as an alert.
Implementations
sourceimpl<'t> AnswerCallbackQuery<'t>
impl<'t> AnswerCallbackQuery<'t>
sourcepub fn show_alert(&mut self) -> &mut AnswerCallbackQuery<'t>
pub fn show_alert(&mut self) -> &mut AnswerCallbackQuery<'t>
An alert will be shown by the client instead of a notification at the top of the chat screen.
sourcepub fn url<T>(&mut self, url: T) -> &mut AnswerCallbackQuery<'t>where
T: Into<Cow<'t, str>>,
pub fn url<T>(&mut self, url: T) -> &mut AnswerCallbackQuery<'t>where
T: Into<Cow<'t, str>>,
URL that will be opened by the user’s client. If you have created a Game and accepted the conditions via @Botfather, specify the URL that opens your game – note that this will only work if the query comes from a callback_game button.
Otherwise, you may use links like t.me/your_bot?start=XXXX that open your bot with a parameter.
sourcepub fn cache_time(&mut self, time: i64) -> &mut AnswerCallbackQuery<'t>
pub fn cache_time(&mut self, time: i64) -> &mut AnswerCallbackQuery<'t>
The maximum amount of time in seconds that the result of the callback query may be cached client-side. Telegram apps will support caching starting in version 3.14. Defaults to 0.