Struct telegram_bot_ars::types::requests::PinChatMessage
source · pub struct PinChatMessage { /* private fields */ }Expand description
Use this method to pin a message in a supergroup or a channel. The bot must be an administrator in the chat for this to work and must have the ‘can_pin_messages’ admin right in the supergroup or ‘can_edit_messages’ admin right in the channel.
Implementations
sourceimpl PinChatMessage
impl PinChatMessage
pub fn disable_notification(&mut self) -> &mut PinChatMessage