Struct telegram_bot_ars::types::requests::SendDocument
source · pub struct SendDocument<'c> { /* private fields */ }Expand description
Use this method to send general files. On success, the sent Message is returned. Bots can currently send files of any type of up to 50 MB in size, this limit may be changed in the future.
Implementations
sourceimpl<'c> SendDocument<'c>
impl<'c> SendDocument<'c>
pub fn new<C, V>(chat: C, document: V) -> SendDocument<'c>where
C: ToChatRef,
V: Into<InputFile>,
pub fn thumb<V>(&mut self, thumb: V) -> &mut SendDocument<'c>where
V: Into<InputFileUpload>,
pub fn caption<T>(&mut self, caption: T) -> &mut SendDocument<'c>where
T: Into<Cow<'c, str>>,
pub fn parse_mode(&mut self, parse_mode: ParseMode) -> &mut SendDocument<'c>
pub fn reply_to<R>(&mut self, to: R) -> &mut SendDocument<'c>where
R: ToMessageId,
pub fn disable_notification(&mut self) -> &mut SendDocument<'c>
pub fn reply_markup<R>(&mut self, reply_markup: R) -> &mut SendDocument<'c>where
R: Into<ReplyMarkup>,