Struct telegram_bot_ars::types::requests::SendLocation
source · pub struct SendLocation { /* private fields */ }Expand description
Use this method to send point on the map.
Implementations
sourceimpl SendLocation
impl SendLocation
pub fn new<C>(chat: C, latitude: f32, longitude: f32) -> SendLocationwhere
C: ToChatRef,
sourcepub fn live_period(&mut self, period: i64) -> &mut SendLocation
pub fn live_period(&mut self, period: i64) -> &mut SendLocation
Period in seconds for which the location will be updated, should be between 60 and 86400.
pub fn disable_notification(&mut self) -> &mut SendLocation
pub fn reply_to<R>(&mut self, to: R) -> &mut SendLocationwhere
R: ToMessageId,
pub fn reply_markup<R>(&mut self, reply_markup: R) -> &mut SendLocationwhere
R: Into<ReplyMarkup>,