ToReplyRequest

Trait ToReplyRequest 

pub trait ToReplyRequest<'b> {
    type Request: Request;

    // Required method
    fn to_reply_request<M>(&'b self, message: M) -> Self::Request
       where M: ToMessageId + ToSourceChat;
}
Use this trait to convert a complex type to corresponding request and reply to the message.

Required Associated Types

type Request: Request

Request type.

Required Methods

fn to_reply_request<M>(&'b self, message: M) -> Self::Request

Convert type to request and reply to the message.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors