Struct telegram_bot_ars::types::Audio
source · pub struct Audio {
pub file_id: String,
pub duration: i64,
pub performer: Option<String>,
pub title: Option<String>,
pub mime_type: Option<String>,
pub file_size: Option<i64>,
}Expand description
This object represents an audio file to be treated as music by the Telegram clients.
Fields
file_id: StringUnique identifier for this file.
duration: i64Duration of the audio in seconds as defined by sender.
performer: Option<String>Performer of the audio as defined by sender or by audio tags.
title: Option<String>Title of the audio as defined by sender or by audio tags.
mime_type: Option<String>MIME type of the file as defined by sender.
file_size: Option<i64>File size.