Struct telegram_bot_ars::types::CallbackQuery
source · pub struct CallbackQuery {
pub id: CallbackQueryId,
pub from: User,
pub message: Option<MessageOrChannelPost>,
pub inline_message_id: Option<String>,
pub chat_instance: String,
pub data: Option<String>,
}Expand description
This object represents an incoming callback query from a callback button in an inline keyboard.
Fields
id: CallbackQueryIdUnique identifier for this query
from: UserSender
message: Option<MessageOrChannelPost>Message with the callback button that originated the query. Note that message content and message date will not be available if the message is too old
inline_message_id: Option<String>Identifier of the message sent via the bot in inline mode, that originated the query.
chat_instance: StringGlobal identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in games.
data: Option<String>Data associated with the callback button. Be aware that a bad client can send arbitrary data in this field.