Struct telegram_bot_ars::types::Channel
source · pub struct Channel {
pub id: ChannelId,
pub title: String,
pub username: Option<String>,
pub invite_link: Option<String>,
}Expand description
This object represents a channel.
Fields
id: ChannelIdUnique identifier for this chat.
title: StringTitle, for supergroups, channels and group chats.
username: Option<String>Username for channel.
invite_link: Option<String>Invite link for this channel, specific to this bot. You can generate a new invite link by using the export_invite_link method.