ChatInviteLink

Struct ChatInviteLink 

pub struct ChatInviteLink {
    pub invite_link: String,
    pub creator: User,
    pub is_primary: bool,
    pub is_revoked: bool,
    pub expire_date: Option<i64>,
    pub member_limit: Option<i64>,
}
Represents an invite link for a chat.

Fields

invite_link: String

The invite link. If the link was created by another chat administrator, then the second part of the link will be replaced with “…”.

creator: User

Creator of the link

is_primary: bool

True, if the link is primary

is_revoked: bool

True, if the link is revoked

expire_date: Option<i64>

Point in time (Unix timestamp) when the link will expire or has been expired

member_limit: Option<i64>

Maximum number of users that can be members of the chat simultaneously after joining the chat via this invite link; 1-99999