Struct telegram_bot_ars::types::Group
source · pub struct Group {
pub id: GroupId,
pub title: String,
pub all_members_are_administrators: bool,
pub invite_link: Option<String>,
}Expand description
This object represents a group.
Fields
id: GroupIdUnique identifier for this chat.
title: StringTitle, for supergroups, channels and group chats.
all_members_are_administrators: boolTrue if a group has ‘All Members Are Admins’ enabled.
invite_link: Option<String>Invite link for this group, specific to this bot. You can generate a new invite link by using the export_invite_link method.