pub struct InlineKeyboardButton { /* private fields */ }
This object represents one button of an inline keyboard.

Implementations

Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes

HTTP or tg:// url to be opened when button is pressed

Pressing the button will prompt the user to select one of their chats, open that chat and insert the bot‘s username and the specified inline query in the input field. Can be empty, in which case just the bot’s username will be inserted.

Pressing the button will insert the bot‘s username and the specified inline query in the current chat’s input field. Can be empty, in which case just the bot’s username will be inserted.