pub struct InlineQueryResultDocument {
    pub id: String,
    pub title: String,
    pub caption: Option<String>,
    pub parse_mode: Option<ParseMode>,
    pub document_url: String,
    pub mime_type: String,
    pub description: Option<String>,
    pub reply_markup: Option<InlineKeyboardMarkup>,
    pub input_message_content: Option<InputMessageContent>,
    pub thumb_url: Option<String>,
    pub thumb_width: Option<i64>,
    pub thumb_height: Option<i64>,
}

Fields

id: String

Unique identifier for this result, 1-64 Bytes

title: String

Title of the result

caption: Option<String>

Caption, 0-1024 characters

parse_mode: Option<ParseMode>

Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.

document_url: String

A valid URL for the file

mime_type: String

Mime type of the content of the file, either “application/pdf” or “application/zip”

description: Option<String>

Short description of the result

reply_markup: Option<InlineKeyboardMarkup>

Inline keyboard attached to the message

input_message_content: Option<InputMessageContent>

Content of the message to be sent

thumb_url: Option<String>

Url of the thumbnail for the result

thumb_width: Option<i64>

Thumbnail width

thumb_height: Option<i64>

Thumbnail height