pub struct InlineQueryResultVideo {
Show 13 fields pub id: String, pub video_url: String, pub mime_type: String, pub thumb_url: String, pub title: String, pub caption: Option<String>, pub parse_mode: Option<ParseMode>, pub video_width: Option<i64>, pub video_height: Option<i64>, pub video_duration: Option<i64>, pub description: Option<String>, pub reply_markup: Option<InlineKeyboardMarkup>, pub input_message_content: Option<InputMessageContent>,
}

Fields

id: String

Unique identifier for this result, 1-64 Bytes

video_url: String

A valid URL for the embedded video player or video file

mime_type: String

Mime type of the content of video url, “text/html” or “video/mp4”

thumb_url: String

Url of the thumbnail (jpeg only) for the video

title: String

Title of the result

caption: Option<String>

Caption of the video to be sent, 0-1024 characters

parse_mode: Option<ParseMode>

Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.

video_width: Option<i64>

Video width

video_height: Option<i64>

Video height

video_duration: Option<i64>

Video duration

description: Option<String>

Short description of the result

reply_markup: Option<InlineKeyboardMarkup>

Inline keyboard attached to the message

input_message_content: Option<InputMessageContent>

Content of the message to be sent