pub struct InputTextMessageContent {
    pub message_text: String,
    pub parse_mode: Option<ParseMode>,
    pub disable_web_page_preview: bool,
}

Fields

message_text: String

Text of the message to be sent, 1-4096 characters

parse_mode: Option<ParseMode>

Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.

disable_web_page_preview: bool

Disables link previews for links in the sent message