Struct telegram_bot_ars::types::KeyboardButton
source · pub struct KeyboardButton { /* private fields */ }Expand description
This object represents one button of the reply keyboard.
Implementations
sourceimpl KeyboardButton
impl KeyboardButton
pub fn new<S>(text: S) -> KeyboardButtonwhere
S: AsRef<str>,
sourcepub fn request_contact(&mut self) -> &mut KeyboardButton
pub fn request_contact(&mut self) -> &mut KeyboardButton
The user’s phone number will be sent as a contact when the button is pressed. Available in private chats only
sourcepub fn request_location(&mut self) -> &mut KeyboardButton
pub fn request_location(&mut self) -> &mut KeyboardButton
The user’s current location will be sent when the button is pressed. Available in private chats only