Struct telegram_bot_ars::types::Sticker
source · pub struct Sticker {
pub file_id: String,
pub file_unique_id: String,
pub width: i64,
pub height: i64,
pub thumb: Option<PhotoSize>,
pub emoji: Option<String>,
pub set_name: Option<String>,
pub file_size: Option<i64>,
}Expand description
This object represents a sticker.
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file.
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
width: i64Sticker width.
height: i64Sticker height.
thumb: Option<PhotoSize>Sticker thumbnail in .webp or .jpg format.
emoji: Option<String>Emoji associated with the sticker.
set_name: Option<String>The name of the sticker set this sticker belongs to.
file_size: Option<i64>File size.