pub struct Supergroup {
pub id: SupergroupId,
pub title: String,
pub username: Option<String>,
pub invite_link: Option<String>,
}Expand description
This object represents a supergroup.
Fields
id: SupergroupIdUnique identifier for this chat.
title: StringTitle, for supergroups, channels and group chats.
username: Option<String>Username for supergroup.
invite_link: Option<String>Invite link for this supergroup, specific to this bot. You can generate a new invite link by using the export_invite_link method.