Struct telegram_bot_ars::types::Video
source · pub struct Video {
pub file_id: String,
pub width: i64,
pub height: i64,
pub duration: i64,
pub thumb: Option<PhotoSize>,
pub mime_type: Option<String>,
pub file_size: Option<i64>,
}Expand description
This object represents a video file.
Fields
file_id: StringUnique identifier for this file.
width: i64Video width as defined by sender.
height: i64Video height as defined by sender.
duration: i64Duration of the video in seconds as defined by sender.
thumb: Option<PhotoSize>Video thumbnail.
mime_type: Option<String>Mime type of a file as defined by sender.
file_size: Option<i64>File size.