UpdateKind

Enum UpdateKind 

pub enum UpdateKind {
Show 13 variants Message(Message), EditedMessage(Message), ChannelPost(ChannelPost), EditedChannelPost(ChannelPost), InlineQuery(InlineQuery), ChosenInlineResult(ChosenInlineResult), CallbackQuery(CallbackQuery), ShippingQuery(ShippingQuery), PreCheckoutQuery(PreCheckoutQuery), Poll(Poll), PollAnswer(PollAnswer), MyChatMember(ChatMemberUpdate), ChatMember(ChatMemberUpdate), // some variants omitted
}
Kind of the incoming update.

Variants



Message(Message)

New incoming message of any kind — text, photo, sticker, etc.



EditedMessage(Message)

New version of a message that is known to the bot and was edited



ChannelPost(ChannelPost)

New incoming channel post of any kind — text, photo, sticker, etc.



EditedChannelPost(ChannelPost)

New version of a channel post that is known to the bot and was edited



InlineQuery(InlineQuery)



ChosenInlineResult(ChosenInlineResult)

The result of an inline query that was chosen by a user and sent to their chat partner. Please see our documentation on the feedback collecting for details on how to enable these updates for your bot.



CallbackQuery(CallbackQuery)



ShippingQuery(ShippingQuery)

New incoming shipping query. Only for invoices with flexible price



PreCheckoutQuery(PreCheckoutQuery)

New incoming pre-checkout query. Contains full information about checkout



Poll(Poll)

New poll state. Bots receive only updates about stopped polls and polls, which are sent by the bot



PollAnswer(PollAnswer)

A user changed their answer in a non-anonymous poll. Bots receive new votes only in polls that were sent by the bot itself



MyChatMember(ChatMemberUpdate)

The bot’s chat member status was updated in a chat. For private chats, this update is received only when the bot is blocked or unblocked by the user.



ChatMember(ChatMemberUpdate)

A chat member’s status was updated in a chat. The bot must be an administrator in the chat and must explicitly specify “chat_member” in the list of allowed_updates to receive these updates.