pub trait ToReplyRequest<'b> {
type Request: Request;
// Required method
fn to_reply_request<M>(&'b self, message: M) -> Self::Request
where M: ToMessageId + ToSourceChat;
}Expand description
Use this trait to convert a complex type to corresponding request and reply to the message.
Required Associated Types
Required Methods
Sourcefn to_reply_request<M>(&'b self, message: M) -> Self::Requestwhere
M: ToMessageId + ToSourceChat,
fn to_reply_request<M>(&'b self, message: M) -> Self::Requestwhere
M: ToMessageId + ToSourceChat,
Convert type to request and reply to the message.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".