Struct telegram_bot_ars::types::InlineKeyboardButton
source · pub struct InlineKeyboardButton { /* private fields */ }Expand description
This object represents one button of an inline keyboard.
Implementations
sourceimpl InlineKeyboardButton
impl InlineKeyboardButton
sourcepub fn callback<T, C>(text: T, callback: C) -> InlineKeyboardButtonwhere
T: AsRef<str>,
C: AsRef<str>,
pub fn callback<T, C>(text: T, callback: C) -> InlineKeyboardButtonwhere
T: AsRef<str>,
C: AsRef<str>,
Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes
sourcepub fn url<T, U>(text: T, url: U) -> InlineKeyboardButtonwhere
T: AsRef<str>,
U: AsRef<str>,
pub fn url<T, U>(text: T, url: U) -> InlineKeyboardButtonwhere
T: AsRef<str>,
U: AsRef<str>,
HTTP or tg:// url to be opened when button is pressed
sourcepub fn switch_inline_query<T, Q>(text: T, query: Q) -> InlineKeyboardButtonwhere
T: AsRef<str>,
Q: AsRef<str>,
pub fn switch_inline_query<T, Q>(text: T, query: Q) -> InlineKeyboardButtonwhere
T: AsRef<str>,
Q: AsRef<str>,
Pressing the button will prompt the user to select one of their chats, open that chat and insert the bot‘s username and the specified inline query in the input field. Can be empty, in which case just the bot’s username will be inserted.
sourcepub fn switch_inline_query_current_chat<T, Q>(
text: T,
query: Q
) -> InlineKeyboardButtonwhere
T: AsRef<str>,
Q: AsRef<str>,
pub fn switch_inline_query_current_chat<T, Q>(
text: T,
query: Q
) -> InlineKeyboardButtonwhere
T: AsRef<str>,
Q: AsRef<str>,
Pressing the button will insert the bot‘s username and the specified inline query in the current chat’s input field. Can be empty, in which case just the bot’s username will be inserted.